Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(47)

Unified Diff: runtime/vm/stub_code_mips.cc

Issue 254723003: Remember all deopt reasons in ic_data, not just the last one. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/stub_code_ia32.cc ('k') | runtime/vm/stub_code_x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/stub_code_mips.cc
===================================================================
--- runtime/vm/stub_code_mips.cc (revision 35455)
+++ runtime/vm/stub_code_mips.cc (working copy)
@@ -1391,7 +1391,7 @@
Register ic_reg = S5;
Register func_reg = temp_reg;
ASSERT(temp_reg == T0);
- __ lw(func_reg, FieldAddress(ic_reg, ICData::function_offset()));
+ __ lw(func_reg, FieldAddress(ic_reg, ICData::owner_offset()));
__ lw(T1, FieldAddress(func_reg, Function::usage_counter_offset()));
__ addiu(T1, T1, Immediate(1));
__ sw(T1, FieldAddress(func_reg, Function::usage_counter_offset()));
@@ -1416,9 +1416,11 @@
ASSERT(num_args > 0);
#if defined(DEBUG)
{ Label ok;
- // Check that the IC data array has NumberOfArgumentsChecked() == num_args.
- // 'num_args_tested' is stored as an untagged int.
- __ lw(T0, FieldAddress(S5, ICData::num_args_tested_offset()));
+ // Check that the IC data array has NumArgsTested() == num_args.
+ // 'NumArgsTested' is stored in the least significant bits of 'state_bits'.
+ __ lw(T0, FieldAddress(S5, ICData::state_bits_offset()));
+ ASSERT(ICData::NumArgsTestedShift() == 0); // No shift needed.
+ __ andi(T0, T0, Immediate(ICData::NumArgsTestedMask()));
__ BranchEqual(T0, num_args, &ok);
__ Stop("Incorrect stub for IC data");
__ Bind(&ok);
@@ -1668,9 +1670,11 @@
__ TraceSimMsg("UnoptimizedStaticCallStub");
#if defined(DEBUG)
{ Label ok;
- // Check that the IC data array has NumberOfArgumentsChecked() == 0.
- // 'num_args_tested' is stored as an untagged int.
- __ lw(T0, FieldAddress(S5, ICData::num_args_tested_offset()));
+ // Check that the IC data array has NumArgsTested() == 0.
+ // 'NumArgsTested' is stored in the least significant bits of 'state_bits'.
+ __ lw(T0, FieldAddress(S5, ICData::state_bits_offset()));
+ ASSERT(ICData::NumArgsTestedShift() == 0); // No shift needed.
+ __ andi(T0, T0, Immediate(ICData::NumArgsTestedMask()));
__ beq(T0, ZR, &ok);
__ Stop("Incorrect IC data for unoptimized static call");
__ Bind(&ok);
« no previous file with comments | « runtime/vm/stub_code_ia32.cc ('k') | runtime/vm/stub_code_x64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698